@@ -42,6 +42,8 @@ class PrettyErrorsConfig():
         self.prefix                 = None
         self.infix                  = None
         self.postfix                = None
+        self.whitelist_paths        = []
+        self.blacklist_paths        = []
         self.reset_stdout           = False
 
 
@@ -99,13 +101,35 @@ def configure(line_length = None, filename_display = None, full_line_newline = N
     )
 
 
+def whitelist(*paths):
+    """If the whitelist has any entries, then only files which begin with
+    one of its entries will be included in the stack trace"""
+    for path in paths:
+        config.whitelist_paths.append(os.path.normpath(path).lower())
+
+
+def blacklist(*paths):
+    """Files which begin with a path on the blacklist will not be
+    included in the stack trace."""
+    for path in paths:
+        config.blacklist_paths.append(os.path.normpath(path).lower())
+
+
 
 def excepthook(exception_type, exception_value, traceback):
     "Replaces sys.excepthook to output pretty errors."
 
+
+    def get_terminal_width():
+        try:
+            return os.get_terminal_size()[0]
+        except Exception:
+            return 79
+
+
     def get_line_length():
         if config.line_length == 0:
-            return os.get_terminal_size()[0]
+            return get_terminal_width()
         else:
             return config.line_length
 
@@ -139,7 +163,7 @@ def excepthook(exception_type, exception_value, traceback):
 
 
     def write_location(path, line, function):
-        line_number = f'{line} '
+        line_number = str(line) + ' '
         output_text('\n')
         if config.filename_display == FILENAME_FULL:
             filename = ""
@@ -232,7 +256,20 @@ def excepthook(exception_type, exception_value, traceback):
 
     tracebacks = []
     while traceback != None:
-        tracebacks.append(traceback)
+        path = os.path.normpath(traceback.tb_frame.f_code.co_filename).lower()
+        if config.whitelist_paths and traceback.tb_next:
+            for white in config.whitelist_paths:
+                if path.startswith(white): break
+            else:
+                traceback = traceback.tb_next
+                continue
+        if traceback.tb_next == None:
+            tracebacks.append(traceback)
+        else:
+            for black in config.blacklist_paths:
+                if path.startswith(black): break
+            else:
+                tracebacks.append(traceback)
         traceback = traceback.tb_next
 
     if config.top_first:
@@ -267,6 +304,7 @@ sys.excepthook = excepthook
 
 
 if __name__ == "__main__":
-    configure(line_number_first = False, filename_display=FILENAME_EXTENDED)
-    raise KeyError#("foo", 1)
+    configure(line_number_first = False, filename_display=FILENAME_FULL)
+    blacklist("c:/")
+    raise KeyError("foo", 1)
         #test
